![example workflow](https://github.com/Ricardo-Santos-21904332/AutoNAV/actions/workflows/test.yml/badge.svg)
[![codecov](https://codecov.io/gh/Ricardo-Santos-21904332/AutoNAV/graph/badge.svg?token=LCR7KDRK3E)](https://codecov.io/gh/Ricardo-Santos-21904332/AutoNAV)

# AutoNAV

## A Python package for simulating UAV Navigation in Satellite-Less Environments

# Run using the cli interface (Easier)

# Run as a library (Advanced)
